# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2


class AnnotationFilterOptions(UniversalBaseModel):
    usual: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include not skipped and not ground truth annotations
    """

    ground_truth: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include ground truth annotations
    """

    skipped: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Include skipped annotations
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
